import React, { ComponentProps, ReactNode } from 'react';
import FeedbackTypes from '../../enums/feedbackTypes';
import variants from '../../enums/variants';
import Skeleton from '../Skeleton/Skeleton';
import { SubcomponentPropsType, StyledSubcomponentType } from '../commonTypes';
import { InteractionFeedbackProps } from '../InteractionFeedback/InteractionFeedback';
export declare type ButtonContainerProps = React.HTMLProps<HTMLButtonElement> & {
    elevation: number;
    color: string;
    variant: variants;
    type: string;
    disabled: boolean;
    feedbackType: FeedbackTypes;
    isLoading?: boolean;
};
export declare enum ButtonTypes {
    button = "button",
    reset = "reset",
    submit = "submit"
}
export declare type ButtonProps = {
    StyledContainer?: StyledSubcomponentType<any>;
    StyledLeftIconContainer?: StyledSubcomponentType;
    StyledRightIconContainer?: StyledSubcomponentType;
    skeletonShimmerProps?: ComponentProps<typeof Skeleton.Shimmer>;
    /**
     * @deprecated The ProgressBar loading skeleton is being replaced by the Skeleton component - use skeletonShimmerProps to customize the Skeleton wrapping the button.
     */
    ProgressBar?: JSX.Element | null;
    containerRef?: React.RefObject<HTMLButtonElement>;
    leftIconContainerRef?: React.RefObject<HTMLDivElement>;
    rightIconContainerRef?: React.RefObject<HTMLDivElement>;
    containerProps?: SubcomponentPropsType;
    interactionFeedbackProps?: Omit<InteractionFeedbackProps, 'children'>;
    leftIconProps?: SubcomponentPropsType;
    rightIconProps?: SubcomponentPropsType;
    children?: ReactNode;
    id?: string;
    disabled?: boolean;
    elevation?: number;
    variant?: variants;
    type?: ButtonTypes;
    color?: string;
    feedbackType?: FeedbackTypes;
    iconPrefix?: string | JSX.Element;
    iconSuffix?: string | JSX.Element;
    isLoading?: boolean;
    isProcessing?: boolean;
    onClick?: React.MouseEventHandler<HTMLButtonElement>;
    onBlur?: (e: React.FocusEvent) => void;
    onFocus?: (e: React.FocusEvent) => void;
    onMouseDown?: (e: React.MouseEvent) => void;
    onMouseUp?: (e: React.MouseEvent) => void;
};
export declare const ButtonContainer: StyledSubcomponentType;
declare const Button: {
    ({ StyledContainer, StyledLeftIconContainer, StyledRightIconContainer, skeletonShimmerProps, ProgressBar, containerProps, interactionFeedbackProps, leftIconProps, rightIconProps, containerRef, leftIconContainerRef, rightIconContainerRef, iconPrefix, iconSuffix, isLoading, isProcessing, children, elevation, feedbackType, variant, type, color, disabled, onClick, onBlur, onFocus, onMouseDown, onMouseUp, id, }: ButtonProps): JSX.Element | null;
    Container: StyledSubcomponentType<any>;
    ButtonTypes: typeof ButtonTypes;
    LeftIconContainer: import("styled-components").StyledComponent<React.ForwardRefExoticComponent<any>, any, {}, never>;
    RightIconContainer: import("styled-components").StyledComponent<React.ForwardRefExoticComponent<any>, any, {}, never>;
};
export default Button;
//# sourceMappingURL=Button.d.ts.map