import React, { FunctionComponent, MouseEventHandler, ReactNode } from 'react';
import { SubcomponentPropsType, StyledSubcomponentType } from '../commonTypes';
export declare type ExpansionIconProps = {
    isCollapsed: boolean;
    onClick: MouseEventHandler;
};
export declare type InternalExpansionIconProps = {
    isCollapsed: boolean;
    groupHeaderPosition: 'above' | 'below';
    onClick: MouseEventHandler;
};
/** Map between column key strings and column properties. */
export declare type Columns = Record<string, Column>;
/** The properties that can be defined for a single column. */
export interface Column {
    name?: string;
    width?: string;
    minTableWidth?: number;
    sortable?: boolean;
    footerContent?: ReactNode;
    sortFunction?: (item1: any, item2: any) => boolean;
    isGroupLabel?: boolean;
    cellComponent?: StyledSubcomponentType;
    rowComponent?: StyledSubcomponentType;
    headerCellComponent?: StyledSubcomponentType;
    groupCellComponent?: StyledSubcomponentType;
}
/**
 * @deprecated Use `Columns`.
 */
export declare type columnTypes = Columns;
/** The data for a single row. */
export declare type RowEntry = Record<string, any>;
export interface SortState {
    sortedColumnKey?: string;
    direction: SortDirection;
}
export declare enum SortDirection {
    noSort = 0,
    ascending = 1,
    descending = 2
}
export declare type TableProps = {
    areGroupsCollapsible?: boolean;
    columnGap?: string;
    columns: Columns;
    data?: Array<RowEntry> | Array<Array<RowEntry>>;
    /**
     * Controls which field is initially sorted.
     * The `[string, boolean]` type for this prop is deprecated. Instead, use `Table.SortState`.
     */
    defaultSort?: SortState | [string, boolean];
    groupHeaderPosition?: 'above' | 'below';
    expansionIconComponent?: FunctionComponent<InternalExpansionIconProps>;
    /**
     * The width of the Table (in px) at which the Table collapses into vertical mode.
     */
    minWidthBreakpoint?: number;
    sortGroups?: boolean;
    StyledCell?: StyledSubcomponentType;
    StyledContainer?: StyledSubcomponentType;
    StyledGroupLabelRow?: StyledSubcomponentType;
    StyledHeader?: StyledSubcomponentType;
    StyledHeaderCell?: StyledSubcomponentType;
    /**
     * Header cells used when the Table is in condensed view
     * based on `minWidthBreakpoint`
     */
    StyledResponsiveHeaderCell?: StyledSubcomponentType;
    StyledRow?: StyledSubcomponentType;
    StyledFooter?: StyledSubcomponentType;
    StyledFooterCell?: StyledSubcomponentType;
    /**
     * If in responsive mode (width < `minWidthBreakpoint`), the `CellContainer` contains the `StyledCell`
     * and the `StyledResponsiveHeaderCellA `CellContainer` contains the `StyledCell`, as well as the `StyledResponsiveHeaderCell` for each cell
     * if width is less than `minWidthBreakpoint`. If width is greater than `minWidthBreakpoint`, then the `CellContainer`
     * only wraps the `StyledCell`.
     */
    StyledCellContainer?: StyledSubcomponentType;
    cellProps?: SubcomponentPropsType;
    containerProps?: SubcomponentPropsType;
    groupLabelRowProps?: SubcomponentPropsType;
    headerProps?: SubcomponentPropsType;
    headerCellProps?: SubcomponentPropsType;
    responsiveHeaderCellProps?: SubcomponentPropsType;
    rowProps?: SubcomponentPropsType;
    containerRef?: React.RefObject<HTMLTableElement>;
    groupLabelRowRef?: React.RefObject<HTMLElement>;
    headerRef?: React.RefObject<HTMLTableRowElement>;
    /**
     * @deprecated Do not use.
     */
    headerCellRef?: React.RefObject<HTMLTableCellElement>;
};
export declare type RowProps = {
    columnGap: string;
    columnWidths: string;
    rowNum?: number;
    reachedMinWidth?: boolean;
    isCollapsed?: boolean;
};
export declare type CellOptions = {
    RenderedCell: StyledSubcomponentType;
    headerColumnKey: string;
    breakPointHit: boolean;
    row: RowEntry;
    index: number;
    indexModifier?: number;
    CollapseExpandedIcon?: any;
    groupIndex?: number;
    isCollapsed?: boolean;
    groupLabelDataString?: string;
    cellProps?: SubcomponentPropsType;
};
//# sourceMappingURL=types.d.ts.map