import React from 'react';
import { TierResult } from 'detect-gpu';
import colorsEnum from '../enums/colors';
import { StyledSubcomponentType } from '../components/commonTypes';
export declare const defaultGlobalStyles: string;
export declare type FoundryColorsType = Record<keyof typeof colorsEnum | string, string>;
export declare type AnalyticsFunctionType = (componentType?: string, eventType?: string, eventArgs?: React.ChangeEvent<HTMLInputElement>, dateTime?: Date, deviceInfo?: Record<string, unknown>, currentURL?: string, props?: any) => any;
export declare type AccessibilityPreferences = {
    prefersReducedMotion: boolean;
};
export declare const defaultAnalyticsFunction: AnalyticsFunctionType;
export declare const defaultAccessibilityPreferences: AccessibilityPreferences;
export declare type FoundryContextType = {
    globalStyles: string;
    colors: FoundryColorsType;
    analyticsFunction: AnalyticsFunctionType;
    performanceInfo: TierResult;
    accessibilityPreferences: AccessibilityPreferences;
    styleConstants: Record<string, number | string>;
};
export declare const FoundryContext: React.Context<FoundryContextType>;
export declare const FoundryProvider: ({ value, children, }: {
    value?: {
        globalStyles?: string | undefined;
        colors?: Record<string, string> | undefined;
        analyticsFunction?: AnalyticsFunctionType | undefined;
        styleConstants?: Record<string, string | number> | undefined;
    } | undefined;
    children: React.ReactNode;
}) => JSX.Element;
export declare const useTheme: () => FoundryContextType;
export declare const useColors: () => FoundryColorsType;
export declare const useAccessibilityPreferences: () => AccessibilityPreferences;
export declare const withGlobalStyle: (Component: StyledSubcomponentType) => React.ForwardRefExoticComponent<any>;
export declare const useAnalytics: () => (componentType: string, eventFunction: any, eventType: string, eventArgs: any, props: any) => void;
//# sourceMappingURL=index.d.ts.map