import variants from '../enums/variants';
export declare type ElevationValues = {
    xOffset: number;
    yOffset: number;
    blur: number;
    opacity: number;
};
/**
 * Calculates the values for shadows based on the provided elevation
 * @param {number} elevation - The elevation to get values for
 * @returns {ElevationValues} The values for each of the shadow values plus color opacity
 */
export declare const calculateElevationValues: (elevation?: number) => ElevationValues;
/**
 * Returns the entire shadow style for a given elevation. If elevation is positive, a drop-shadow filter is returned.
 * If the elevation is negative, a box-shadow is returned and is inset. If elevation is 0, emptystring is returned.
 * @param {number} elevation - The elevation to get the shadow style for
 * @param {string} shadowColor - The color to be used for the shadow in hex or rgba format
 * @returns {string} The css style property and value
 */
export declare const getShadowStyle: (elevation: number | undefined, shadowColor: string) => string;
/**
 * Determines the style of the of the tag component for the dropdown
 * @param dropdownVariant - The dropdown variant
 * @param tagVariant - The tag variant
 * @param dropdownColor - The color prop passed into the dropdown
 * @param transparentColor - The transparent color provided from the useTheme hook
 */
export declare const getDropdownTagStyle: (dropdownVariant: variants, tagVariant: variants, dropdownColor: string, transparentColor: string) => string;
//# sourceMappingURL=styles.d.ts.map